@@ -1,13 +1,12 @@
 package POE::Component::SmokeBox::Uploads::CPAN::Mini;
+$POE::Component::SmokeBox::Uploads::CPAN::Mini::VERSION = '1.02';
+#ABSTRACT: Obtain uploaded CPAN modules via a CPAN::Mini mirror
 
 use strict;
 use warnings;
 use POE qw(Wheel::Run);
 use Carp;
 use CPAN::Mini;
-use vars qw($VERSION);
-
-$VERSION = '1.00';
 
 sub spawn {
   my $package = shift;
@@ -149,12 +148,21 @@ sub _wheel_stderr {
 }
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 POE::Component::SmokeBox::Uploads::CPAN::Mini - Obtain uploaded CPAN modules via a CPAN::Mini mirror
 
+=head1 VERSION
+
+version 1.02
+
 =head1 SYNOPSIS
 
   # Create a CPAN::Mini::Devel mirror
@@ -219,7 +227,7 @@ Other L<CPAN::Mini> options may be specified.
   'class', specify the CPAN::Mini class to use, defaults to CPAN::Mini;
   'force', check all directories, even if indices are unchanged, default is true;
   'skip_perl', skip the major language distributions: perl, parrot, and ponier, default false;
-  
+
 There are some debugging options:
 
   'debug', if set to true the component will print output from update_mirror();
@@ -232,7 +240,7 @@ Returns an object.
 
 =head1 METHODS
 
-=over 
+=over
 
 =item C<session_id>
 
@@ -246,7 +254,7 @@ Terminates the component.
 
 =head1 INPUT EVENTS
 
-=over 
+=over
 
 =item C<shutdown>
 
@@ -268,20 +276,21 @@ If C<dump> has been set to true in the C<spawn> constructor then these additiona
   'buffer', an arrayref containing the STDOUT messages from the update_mirror() call;
   'errors', an arrayref containing the STDERR messages from the update_mirror() call;
 
-=head1 AUTHOR
-
-Chris C<BinGOs> Williams <chris@bingosnet.co.uk>
-
-=head1 LICENSE
-
-Copyright E<copy> Chris Williams
-
-This module may be used, modified, and distributed under the same terms as Perl itself. Please see the license that came with your Perl distribution for details.
-
 =head1 SEE ALSO
 
 L<POE>
 
 L<CPAN::Mini>
 
+=head1 AUTHOR
+
+Chris Williams <chris@bingosnet.co.uk>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Chris Williams.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
